"""
    EMIL PartnerService

    The EMIL PartnerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.partner
from eis.partner.model.partner_relation_type_class import PartnerRelationTypeClass
globals()['PartnerRelationTypeClass'] = PartnerRelationTypeClass
from eis.partner.model.get_partner_relation_type_class import GetPartnerRelationTypeClass


class TestGetPartnerRelationTypeClass(unittest.TestCase):
    """GetPartnerRelationTypeClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetPartnerRelationTypeClass(self):
        """Test GetPartnerRelationTypeClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetPartnerRelationTypeClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
