"""
    EMIL PartnerService

    The EMIL PartnerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.partner
from eis.partner.api.partner_relations_api import PartnerRelationsApi  # noqa: E501


class TestPartnerRelationsApi(unittest.TestCase):
    """PartnerRelationsApi unit test stubs"""

    def setUp(self):
        self.api = PartnerRelationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_partner_relation(self):
        """Test case for create_partner_relation

        Create the partner relation  # noqa: E501
        """
        pass

    def test_delete_partner_relation(self):
        """Test case for delete_partner_relation

        Delete the partner-relation  # noqa: E501
        """
        pass

    def test_get_partner_relation(self):
        """Test case for get_partner_relation

        Retrieve the partner relation  # noqa: E501
        """
        pass

    def test_get_partner_relation_type(self):
        """Test case for get_partner_relation_type

        Retrieve the partner relation type  # noqa: E501
        """
        pass

    def test_list_partner_relation_types(self):
        """Test case for list_partner_relation_types

        List partner relation types  # noqa: E501
        """
        pass

    def test_list_partner_relations(self):
        """Test case for list_partner_relations

        List partner relations  # noqa: E501
        """
        pass

    def test_update_partner_relation(self):
        """Test case for update_partner_relation

        Update the partner relation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
