"""
    EMIL PartnerService

    The EMIL PartnerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.partner
from eis.partner.api.partners_api import PartnersApi  # noqa: E501


class TestPartnersApi(unittest.TestCase):
    """PartnersApi unit test stubs"""

    def setUp(self):
        self.api = PartnersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_partner(self):
        """Test case for create_partner

        Create the partner  # noqa: E501
        """
        pass

    def test_delete_partner(self):
        """Test case for delete_partner

        Delete the partner  # noqa: E501
        """
        pass

    def test_get_partner(self):
        """Test case for get_partner

        Retrieve the partner  # noqa: E501
        """
        pass

    def test_list_partners(self):
        """Test case for list_partners

        List partners  # noqa: E501
        """
        pass

    def test_list_relations_for_partner(self):
        """Test case for list_relations_for_partner

        List grouped relations for partner  # noqa: E501
        """
        pass

    def test_tag_partner(self):
        """Test case for tag_partner

        Update the partner  # noqa: E501
        """
        pass

    def test_update_partner(self):
        """Test case for update_partner

        Update the partner  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
